Performs the INCATome DEG identification for microarray data, consisting of an overlap of at least two out of four DEG tests (TTest, Limma, RankProd and SAM).
a vector specifying type of samples, 0 being control and 1 being condition.
wcol
an integer specifying the number of the column where Gene Names can be found in the gene annotation table.
filt
logical, TRUE if a set of negative control probes are to be used for filtering. Filtering is performed by removing any probes for which the average intensities are lower than the "negative" mean +/- 1.5 "negative" deviation.
selneg
a character or vector containing the negative control probe names for filtering.
base
an integer specifying the log base. Default is 2.
highlight
a character vector specifying a set of genes of interest. These will be highlighted in the graphical representations.
Value
A List object containing the INCA DEG output for significant DEGs with INCA DEG Score >= 2, as well as all individual outputs from the different tests. Additionally, volcanoplots for each test will be generated.
# NOT RUN {#Load the INCATome Datasetdata(INCATomeData)
attach(INCATomeData)
out=INCA.DEG(RGdataDS,c(0,0,0,1,1,1),8,filt=TRUE,
selneg="NegativeControl", highlight=c("ACTB","PABPC1"))
# }