INCA.DyeSwap: DyeSwap Method for two-color microarray data
Description
Performs a dyeswap correction by an averaging method for two-color microarray data.
Usage
INCA.DyeSwap(x, dsvect)
Arguments
x
an RGList object
dsvect
an integer vector specifying dyeswapped microarrays. Needs to be of same length as number of arrays contained in the RGList object. Labelling should start from 1 and associates dyeswapped microarray with "-i".
Value
a new RGList object containing the dyeswapped array data.