an integer specifying the number of the column where Gene Names can be found in the gene annotation table.
spikeIn
logical, TRUE to highlight SpikeIn Probes. Requires input in SpikeFile.
SpikeFile
a data.frame specifying the Spike In probe names if spikeIn=TRUE in a column called "Probe" and the expected relative amounts for each dye, respectively in a "Cy5" and "Cy3" column. For example, a given probe might be expected in a 3:1 ratio thus column "Cy5" would specify 3 and column "Cy3" would specify 1.
prefix
a character specifying the prefix to be used when saving the plot in a jpeg file.
highlight
a character vector specifying a set of genes of interest to be highlighted in the plot.
# NOT RUN {#Load the INCATome Datasetdata(INCATomeData)
attach(INCATomeData)
INCA.MAPlot(RGdata,8,spikeIn=TRUE,SpikeFile=sdata, highlight=c("ACTB","PABPC1"))
# }