a data.frame specifying the Spike In probe names in a column called "Probe" and the expected relative amounts for each dye, respectively in a "Cy5" and "Cy3" column. For example, a given probe might be expected in a 3:1 ratio thus column "Cy5" would specify 3 and column "Cy3" would specify 1.
wcol
an integer specifying the number of the column where Gene Names can be found in the gene annotation table.
base
an integer specifying the log base. Default is 2.
mva
logical, TRUE to plot MA plots before and after normalisation for each array.
highlight
a character vector specifying a set of genes of interest. These will be highlighted in the graphical representations.
Value
A new RGList object containing the normalised array data. Additionally, if mva is TRUE, MA plots before and after normalisations will be generated for each arrays.